==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/LogInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface LogInfoFluent<A extends me.snowdrop.istio.mixer.adapter.stackdriver.LogInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHttpMapping instead.
 * @return The buildable object.
 */
@Deprecated public HttpRequestMapping getHttpMapping();
    public HttpRequestMapping buildHttpMapping();
    public A withHttpMapping(HttpRequestMapping httpMapping);
    public Boolean hasHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> withNewHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> withNewHttpMappingLike(HttpRequestMapping item);
    public LogInfoFluent.HttpMappingNested<A> editHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> editOrNewHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> editOrNewHttpMappingLike(HttpRequestMapping item);
    public A addToLabelNames(int index,String item);
    public A setToLabelNames(int index,String item);
    public A addToLabelNames(String... items);
    public A addAllToLabelNames(Collection<String> items);
    public A removeFromLabelNames(String... items);
    public A removeAllFromLabelNames(Collection<String> items);
    public List<String> getLabelNames();
    public String getLabelName(int index);
    public String getFirstLabelName();
    public String getLastLabelName();
    public String getMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLabelNames(List<String> labelNames);
    public A withLabelNames(String... labelNames);
    public Boolean hasLabelNames();
    public String getPayloadTemplate();
    public A withPayloadTemplate(String payloadTemplate);
    public Boolean hasPayloadTemplate();
    
/**
 * This method has been deprecated, please use method buildSinkInfo instead.
 * @return The buildable object.
 */
@Deprecated public SinkInfo getSinkInfo();
    public SinkInfo buildSinkInfo();
    public A withSinkInfo(SinkInfo sinkInfo);
    public Boolean hasSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> withNewSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> withNewSinkInfoLike(SinkInfo item);
    public LogInfoFluent.SinkInfoNested<A> editSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> editOrNewSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> editOrNewSinkInfoLike(SinkInfo item);

    public interface HttpMappingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpRequestMappingFluent<LogInfoFluent.HttpMappingNested<N>>{

        
    public N and();    public N endHttpMapping();
}
    public interface SinkInfoNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SinkInfoFluent<LogInfoFluent.SinkInfoNested<N>>{

        
    public N and();    public N endSinkInfo();
}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/stackdriver/LogInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.stackdriver;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface LogInfoFluent<A extends me.snowdrop.istio.mixer.adapter.stackdriver.LogInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHttpMapping instead.
 * @return The buildable object.
 */
@Deprecated public HttpRequestMapping getHttpMapping();
    public HttpRequestMapping buildHttpMapping();
    public A withHttpMapping(HttpRequestMapping httpMapping);
    public Boolean hasHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> withNewHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> withNewHttpMappingLike(HttpRequestMapping item);
    public LogInfoFluent.HttpMappingNested<A> editHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> editOrNewHttpMapping();
    public LogInfoFluent.HttpMappingNested<A> editOrNewHttpMappingLike(HttpRequestMapping item);
    public A addToLabelNames(int index,String item);
    public A setToLabelNames(int index,String item);
    public A addToLabelNames(String... items);
    public A addAllToLabelNames(Collection<String> items);
    public A removeFromLabelNames(String... items);
    public A removeAllFromLabelNames(Collection<String> items);
    public List<String> getLabelNames();
    public String getLabelName(int index);
    public String getFirstLabelName();
    public String getLastLabelName();
    public String getMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLabelNames(List<String> labelNames);
    public A withLabelNames(String... labelNames);
    public Boolean hasLabelNames();
    public A addNewLabelName(String arg1);
    public A addNewLabelName(StringBuilder arg1);
    public A addNewLabelName(StringBuffer arg1);
    public String getPayloadTemplate();
    public A withPayloadTemplate(String payloadTemplate);
    public Boolean hasPayloadTemplate();
    public A withNewPayloadTemplate(String arg1);
    public A withNewPayloadTemplate(StringBuilder arg1);
    public A withNewPayloadTemplate(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSinkInfo instead.
 * @return The buildable object.
 */
@Deprecated public SinkInfo getSinkInfo();
    public SinkInfo buildSinkInfo();
    public A withSinkInfo(SinkInfo sinkInfo);
    public Boolean hasSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> withNewSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> withNewSinkInfoLike(SinkInfo item);
    public LogInfoFluent.SinkInfoNested<A> editSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> editOrNewSinkInfo();
    public LogInfoFluent.SinkInfoNested<A> editOrNewSinkInfoLike(SinkInfo item);

    public interface HttpMappingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpRequestMappingFluent<LogInfoFluent.HttpMappingNested<N>>{

        
    public N and();    public N endHttpMapping();
}
    public interface SinkInfoNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SinkInfoFluent<LogInfoFluent.SinkInfoNested<N>>{

        
    public N and();    public N endSinkInfo();
}


}
